from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi
from wds_client.api.instances_api import InstancesApi
from wds_client.api.records_api import RecordsApi
from wds_client.api.schema_api import SchemaApi
