# coding: utf-8

"""
    Workspace Data Service

    This page lists both current and proposed APIs. The proposed APIs which have not yet been implemented are marked as deprecated. This is incongruous, but by using the deprecated flag, we can force swagger-ui to display those endpoints differently.  Error codes and responses for proposed APIs are likely to change as we gain more clarity on their implementation.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.schema_api import SchemaApi  # noqa: E501
from wds_client.rest import ApiException


class TestSchemaApi(unittest.TestCase):
    """SchemaApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.schema_api.SchemaApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attribute(self):
        """Test case for delete_attribute

        Delete attribute (pending)  # noqa: E501
        """
        pass

    def test_delete_record_type(self):
        """Test case for delete_record_type

        Delete record type  # noqa: E501
        """
        pass

    def test_describe_all_record_types(self):
        """Test case for describe_all_record_types

        Describe all record types  # noqa: E501
        """
        pass

    def test_describe_attribute(self):
        """Test case for describe_attribute

        Describe attribute (pending)  # noqa: E501
        """
        pass

    def test_describe_record_type(self):
        """Test case for describe_record_type

        Describe record type  # noqa: E501
        """
        pass

    def test_update_attribute(self):
        """Test case for update_attribute

        Update attribute (pending)  # noqa: E501
        """
        pass

    def test_update_record_type(self):
        """Test case for update_record_type

        Update record type (pending)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
