# coding: utf-8

"""
    Workspace Data Service

    This page lists both current and proposed APIs. The proposed APIs which have not yet been implemented are marked as deprecated. This is incongruous, but by using the deprecated flag, we can force swagger-ui to display those endpoints differently.  Error codes and responses for proposed APIs are likely to change as we gain more clarity on their implementation.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi  # noqa: E501
from wds_client.rest import ApiException


class TestGeneralWDSInformationApi(unittest.TestCase):
    """GeneralWDSInformationApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.general_wds_information_api.GeneralWDSInformationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_status_get(self):
        """Test case for status_get

        Gets health status for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#health for details)  # noqa: E501
        """
        pass

    def test_version_get(self):
        """Test case for version_get

        Gets related git and build version info for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#info for details)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
