# coding: utf-8

# flake8: noqa

"""
    Workspace Data Service

    This page lists both current and proposed APIs. The proposed APIs which have not yet been implemented are marked as deprecated. This is incongruous, but by using the deprecated flag, we can force swagger-ui to display those endpoints differently.  Error codes and responses for proposed APIs are likely to change as we gain more clarity on their implementation.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.2.39"

# import apis into sdk package
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi
from wds_client.api.instances_api import InstancesApi
from wds_client.api.records_api import RecordsApi
from wds_client.api.schema_api import SchemaApi

# import ApiClient
from wds_client.api_client import ApiClient
from wds_client.configuration import Configuration
from wds_client.exceptions import OpenApiException
from wds_client.exceptions import ApiTypeError
from wds_client.exceptions import ApiValueError
from wds_client.exceptions import ApiKeyError
from wds_client.exceptions import ApiException
# import models into sdk package
from wds_client.models.attribute_schema import AttributeSchema
from wds_client.models.batch_operation import BatchOperation
from wds_client.models.batch_record_request import BatchRecordRequest
from wds_client.models.batch_response import BatchResponse
from wds_client.models.build import Build
from wds_client.models.commit import Commit
from wds_client.models.component import Component
from wds_client.models.components import Components
from wds_client.models.db_component import DbComponent
from wds_client.models.error_response import ErrorResponse
from wds_client.models.git import Git
from wds_client.models.inline_object import InlineObject
from wds_client.models.record_attribute_definition import RecordAttributeDefinition
from wds_client.models.record_query_response import RecordQueryResponse
from wds_client.models.record_request import RecordRequest
from wds_client.models.record_response import RecordResponse
from wds_client.models.record_type_schema import RecordTypeSchema
from wds_client.models.request_body_search import RequestBodySearch
from wds_client.models.search_operator import SearchOperator
from wds_client.models.search_request import SearchRequest
from wds_client.models.search_sort_direction import SearchSortDirection
from wds_client.models.stack_trace_element import StackTraceElement
from wds_client.models.status_response import StatusResponse
from wds_client.models.tsv_upload_response import TsvUploadResponse
from wds_client.models.version_response import VersionResponse

